@@ -12,7 +12,7 @@ import requests
 from jsonutils.config.locals import decimal_separator, thousands_separator
 from jsonutils.exceptions import JSONQueryException, JSONSingletonException
 from jsonutils.functions.decorators import catch_exceptions, return_str_or_datetime
-from jsonutils.query import All, AllChoices, ExtractYear, I, QuerySet, ValuesList
+from jsonutils.query import All, AllChoices, ExtractYear, I, QuerySet
 from jsonutils.utils.retry import retry_function
 from jsonutils.utils.urls import join_paths
 
@@ -423,6 +423,7 @@ def parse_datetime(
     only_date=False,
     fail_silently=False,
     return_string=False,
+    is_timestamp=False,
     tzone="utc",
 ):
     """
@@ -435,6 +436,19 @@ def parse_datetime(
     ):
         raise TypeError("Invalid type arguments. All keyword arguments must be boolean")
 
+    if only_check and is_timestamp:
+        raise ValueError("Cannot set both `only_check` and `is_timestamp` to True")
+
+    if is_timestamp and parse_int(s, only_check=True):
+        parsed_datetime = datetime.fromtimestamp(parse_int(s))
+        if tzone_aware:
+            parsed_datetime = parsed_datetime.replace(tzinfo=pytz.timezone(tzone))
+        if only_date:
+            parsed_datetime = parsed_datetime.replace(
+                hour=0, minute=0, second=0, microsecond=0
+            )
+        return parsed_datetime
+
     if isinstance(s, (date, datetime)):
         if only_check:
             return True
@@ -854,7 +868,3 @@ def _parse_html_table(table, parse_links, link_prefix):
     result = base.JSONObject([dict(zip(h, i)) for i in d])
 
     return result
-
-
-if __name__ == "__main__":
-    parse_int("  - $2 USD")
